------------------------------------------------------------------------
-- @class Seed
-- Class representing a seed, that is to say, a player-to-be
-- Can jump lightly and give birth to a Core
------------------------------------------------------------------------
class "Seed"{
    x_pos   =   0,
    y_pos   =   0
}


------------------------------------------------------------------------
-- Function to init a seed anywhere
-- @param p_x x position in the world
-- @param p_y y position in the world
-- @param p_world (optionnal) physical world
------------------------------------------------------------------------
function Seed:__init__(p_x, p_y, p_world)
    self.x_pos  =   p_x
    self.y_pos  =   p_y
    self.image  =   love.graphics.newImage("res/images/sprites/oak.png") -- Default image
    self.jumps  =   2
    self.time   =   0
    self.last_jump  =   0
    --Particles
    flare = love.graphics.newImage("res/images/sprites/flare.png")

    self.creation_effect =   love.graphics.newParticleSystem(flare, 1000)
    self.creation_effect:setEmissionRate(500)
    self.creation_effect:setSpeed(200, 400)
    self.creation_effect:setSizes(1, 2)
    self.creation_effect:setColors(230, 255, 230, 255, 128, 255, 128, 0)
    self.creation_effect:setPosition(400, 300)
    self.creation_effect:setLifetime(1.3)
    self.creation_effect:setParticleLife(1.3)
    self.creation_effect:setDirection(0)
    self.creation_effect:setSpread(360)
    self.creation_effect:setTangentialAcceleration(200)
    self.creation_effect:setRadialAcceleration(-800)
    self.creation_effect:stop()


    self.jump_effect     =   love.graphics.newParticleSystem(flare, 1000)
    self.jump_effect:setEmissionRate(20)
    self.jump_effect:setSpeed(30, 40)
    self.jump_effect:setSizes(1, 2)
    self.jump_effect:setColors(230, 255, 230, 255, 128, 255, 128, 0)
    self.jump_effect:setPosition(400, 300)
    self.jump_effect:setLifetime(0.5)
    self.jump_effect:setParticleLife(0.5)
    self.jump_effect:setDirection(0)
    self.jump_effect:setSpread(180)
    self.jump_effect:setTangentialAcceleration(2)
    self.jump_effect:setRadialAcceleration(-8)
    self.jump_effect:stop()

    --Physics?
    if p_world then
        self:setWorld(p_world)
    end
end


function Seed:setWorld(p_world)
        self.world      =   p_world
        center_y        =   self.image:getWidth()  / 2 + self.y_pos
        center_x        =   self.image:getHeight() / 2 + self.x_pos
        self.body       =   love.physics.newBody( p_world, center_x, center_y, "dynamic" )
        self.shape      =   love.physics.newCircleShape(self.image:getWidth() / 3) --the ball's shape has a radius of 20
        self.fixture    =   love.physics.newFixture(self.body, self.shape, 1)
        self.fixture:setRestitution(0.15)
        self.body:setMass(2)
        self.body:setLinearDamping(0.1)
        self.body:getAngularDamping(0.1)
end

------------------------------------------------------------------------
-- Updates the position of the seed
-- @param p_dt delta time since last frame
------------------------------------------------------------------------
function Seed:update(p_dt)
    self.time   =   self.time + p_dt
    self.x_pos  =   self.body:getX()
    self.y_pos  =   self.body:getY()

    self.jump_effect:update(p_dt)
    self.creation_effect:update(p_dt)
end


------------------------------------------------------------------------
-- Returns the drawable parameters of the object
-- @return image, x, y, angle, 1, 1, ox, oy
------------------------------------------------------------------------
function Seed:getDrawable()
    return self.image, self.x_pos, self.y_pos, self.body:getAngle(), 1, 1, self.image:getWidth()/2, self.image:getHeight()/2
end


function Seed:setJumpLeft(p_number)
    if p_number then
        self.jumps  =   p_number
    end
end

------------------------------------------------------------------------
-- Makes the seed jump slightly. Implies there are jumps left, and
-- that the last jump was 1second ago
-- @param p_direction string right|left
------------------------------------------------------------------------
function Seed:jump(p_direction)
    if self.jumping then return end
    if self.jumps <= 0 then return end
    if self.time - self.last_jump <= 0.5 then return end

    self.last_jump = self.time
    self.jump_effect:setPosition(self.x_pos, self.y_pos)
    self.jump_effect:start()
    if not p_direction then
        p_direction = "right"
    end

    if p_direction == "right" then
        self.body:applyLinearImpulse( 500, -500 )
    else
        self.body:applyLinearImpulse( -500, -500 )
    end
    self.jumps   =   self.jumps - 1

end


function Seed:plant()
    self.creation_effect:setPosition(self.x_pos, self.y_pos)
    self.creation_effect:start()

end

function Seed:setImage(p_img)
    print(p_img)
    self.image  =   p_img

end

function Seed:setPos(p_x, p_y)
    if p_x then
        self.x_pos  =   p_x
    end
    if p_y then
        self.y_pos  =   p_y
    end

end

function Seed:getJumps()
    return self.jumps
end
