------------------------------------------------------------------------
-- @file play_gamestates.lua
-- File storing the differents gamestates of ingame modes and their callbacks
------------------------------------------------------------------------


------------------------------------------------------------------------
-- SEEDING
------------------------------------------------------------------------
function seeding:init()

    seedcam =   camera(0, 0, 1, 0) -- Camera at origin point, with no zoom
    seeding.speedcam    =   10
    -- Physics
    love.physics.setMeter(64)
    world = love.physics.newWorld(0, 7.91*64, true)

    --~ Game Objects group
    game_objects=   {}
    print("jumps for that: "..chosen_seed:getJumps())

    seed    =   chosen_seed
    chosen_seed:setWorld(world)
    current_level = Level("data/levels/level_0", world)
    table.insert(game_objects, current_level)
    table.insert(game_objects, seed)


    --~ Particles group
    particles   =   {}
    table.insert(particles, seed.jump_effect)
    table.insert(particles, seed.creation_effect)


    --~ TODO:make it the borders of the level
    screenright         =   love.graphics.getHeight()
    screenright         =   love.graphics.getWidth()

    border_rectangle    =   love.physics.newRectangleShape(10, current_level.image:getHeight() )

    border_left         =   {}
    border_left.body    =   love.physics.newBody(world, 0, current_level.image:getHeight()/2, "static") --Anchor point
    border_left.fixture =   love.physics.newFixture(border_left.body, border_rectangle)

    border_right        =   {}
    border_right.body   =   love.physics.newBody(world,current_level.image:getWidth(), current_level.image:getHeight()/2, "static") --Anchor point
    border_right.fixture=   love.physics.newFixture(border_right.body, border_rectangle)


end


function seeding:draw()
    love.graphics.setFont(standard_font)
    --Drawing _moving_ world
    seedcam:attach()
    for idx,obj in ipairs(game_objects) do
        love.graphics.draw(obj:getDrawable())
    end

    for idx,p in ipairs(particles) do
        love.graphics.draw(p, 0, 0)
    end

    --TODO: remove this (debug)
    --~ print (border_left.body:getWorldPoints(border_left.body:getPosition()))

    -- INFO: keep that as an example: don't fall into that bug again:
    -- body: getPosition returns the FRACKING CENTER of the shape, not it's DARN TOPLEFT CORNER
    x, y = border_left.body:getPosition()
    love.graphics.rectangle("fill", x, y - current_level.image:getHeight()/2, 10, current_level.image:getHeight() )

    x, y = border_right.body:getPosition()
    love.graphics.rectangle("fill", x, y - current_level.image:getHeight()/2, 10, current_level.image:getHeight() )

    --Drawing _fixed_ HUD
    seedcam:detach()
    love.graphics.print( "You have "..seed.jumps.." jumps remaining.", 10, 10 )

end


function seeding:update(dt)

    world:update(dt)

    for idx,obj in ipairs(game_objects) do
        obj:update(dt)
    end

    for idx,p in ipairs(particles) do
        p:update(dt)
    end

    local point={}
    point.x, point.y=seed.x_pos, seed.y_pos
    track_point(seedcam, point)

end


function seeding:keypressed(key, unicode)

    if key == "escape" then
        love.event.quit()
    end


    if key == " " then --spacebar pressed
        print("planting!")
        seed:plant()
    end

    if key == "right" then
        seed:jump("right")
    end

    if key == "left" then
        seed:jump("left")
    end

end

